@@ -12,7 +12,7 @@ sub root :Chained(../root) PathPart('') CaptureArgs(1) ($self, $c, $collection,
 }
 
   sub setup :Chained(root) PathPart('') CaptureArgs(0) ($self, $c, $todo) {
-    $c->view('HTML::Todo', todo => $todo);
+    $c->view('HTML::Todos::Todo', todo => $todo);
     $c->action->next($todo);
   }
 
